/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */
package com.yifu.cloud.plus.v1.yifu.salary.vo;

import com.alibaba.excel.annotation.ExcelProperty;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.yifu.cloud.plus.v1.yifu.common.core.vo.RowIndex;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.ExcelAttribute;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotBlank;
import java.io.Serializable;

/**
 * 申报对象表
 *
 * @author huyc
 * @date 2022-08-11 10:56:10
 */
@Data
public class TStatisticsDeclarerVo extends RowIndex implements Serializable {

	/**
	 * ID
	 */
	@TableId(type = IdType.ASSIGN_ID)
	@NotBlank(message = "ID 不能为空")
	@Length(max = 32, message = "ID 不能超过32 个字符")
	@ExcelAttribute(name = "ID", isNotEmpty = true, errorInfo = "ID 不能为空", maxLength = 32)
	@Schema(description = "ID")
	@ExcelProperty("ID")
	private String id;
	/**
	 * 申报单位
	 */
	@Length(max = 50, message = "申报单位 不能超过50 个字符")
	@ExcelAttribute(name = "申报单位", maxLength = 50)
	@Schema(description = "申报单位")
	@ExcelProperty("申报单位")
	private String declareUnit;
	/**
	 * 申报月份
	 */
	@NotBlank(message = "申报月份 不能为空")
	@Length(max = 6, message = "申报月份 不能超过6 个字符")
	@ExcelAttribute(name = "申报月份", isNotEmpty = true, errorInfo = "申报月份 不能为空", maxLength = 6)
	@Schema(description = "申报月份")
	@ExcelProperty("申报月份")
	private String declareMonth;
	/**
	 * 员工姓名
	 */
	@Length(max = 20, message = "员工姓名 不能超过20 个字符")
	@ExcelAttribute(name = "员工姓名", maxLength = 20)
	@Schema(description = "员工姓名")
	@ExcelProperty("员工姓名")
	private String empName;
	/**
	 * 身份证号
	 */
	@Length(max = 20, message = "身份证号 不能超过20 个字符")
	@ExcelAttribute(name = "身份证号", maxLength = 20)
	@Schema(description = "身份证号")
	@ExcelProperty("身份证号")
	private String empIdcard;
	/**
	 * 手机号码
	 */
	@Length(max = 11, message = "手机号码 不能超过11 个字符")
	@ExcelAttribute(name = "手机号码", maxLength = 11)
	@Schema(description = "手机号码")
	@ExcelProperty("手机号码")
	private String empPhone;
	/**
	 * 人员状态
	 */
	@Length(max = 2, message = "人员状态 不能超过2 个字符")
	@ExcelAttribute(name = "人员状态", maxLength = 2)
	@Schema(description = "人员状态")
	@ExcelProperty("人员状态")
	private String empStatus;
	/**
	 * 任职受雇从业类型
	 */
	@Length(max = 2, message = "任职受雇从业类型 不能超过2 个字符")
	@ExcelAttribute(name = "任职受雇从业类型", maxLength = 2)
	@Schema(description = "任职受雇从业类型")
	@ExcelProperty("任职受雇从业类型")
	private String occupationType;
	/**
	 * 任职受雇从业日期
	 */
	@Length(max = 20, message = "任职受雇从业日期 不能超过20 个字符")
	@ExcelAttribute(name = "任职受雇从业日期", maxLength = 20)
	@Schema(description = "任职受雇从业日期")
	@ExcelProperty("任职受雇从业日期")
	private String occupationMonth;
	/**
	 * 本月是否申报
	 */
	@Length(max = 1, message = "本月是否申报 不能超过1 个字符")
	@ExcelAttribute(name = "本月是否申报", maxLength = 1)
	@Schema(description = "本月是否申报")
	@ExcelProperty("本月是否申报")
	private String isDeclare;
	/**
	 * 不申报原因
	 */
	@Length(max = 200, message = "不申报原因 不能超过200 个字符")
	@ExcelAttribute(name = "不申报原因", maxLength = 200)
	@Schema(description = "不申报原因")
	@ExcelProperty("不申报原因")
	private String undeclareReason;

}
